stranding [![Build Status](https://travis-ci.org/23andMe/stranding.svg?branch=master)](https://travis-ci.org/23andMe/stranding)
=================
Determines genome stranding for sequences mapped to a human reference assembly 
